@@ -1,7 +1,7 @@
 import numpy as np
 import pandas as pd
 from scipy import optimize, stats
-from Model import Model
+from .Model import Model
 
 
 class ChangePointModel(Model):
