@@ -52,13 +52,14 @@ class NMEC:
         pass
 
     def model_with_changepoint(self, df: pd, cp_type="SLR"):
-        my_model = ChangePointModel(df, model_name = cp_type)
+        my_model = ChangePointModel(df, model_name=cp_type)
         
         if cp_type.upper() in ["3PH", "3PC"]:
             df = my_model.df
             train_estimate = my_model.train(df.dropna().copy())
 
-            return {"data": train_estimate
+            return {"occupied model": my_model.p, "unoccupied model": None,
+                    "data": train_estimate
                     # 'metrics': my_model.metrics(train_estimate)
                     }
 
@@ -71,14 +72,14 @@ class NMEC:
                 df_occ = my_model.df
                 df_unocc = None
                 
-            train_estimate= my_model.train(df_occ.dropna().copy())
+            train_estimate = my_model.train_SLR(df_occ.dropna().copy())
             
             if df_unocc is not None:
-                train_estimate = my_model.train(
+                train_estimate = my_model.train_SLR(
                     df_unocc.dropna().copy(), train_estimate)
 
             if train_estimate is not None:
-                return {
+                return {"occupied model": my_model.lm, "unoccupied model": my_model.lm_unocc,
                         "data": train_estimate
                         # 'metrics': my_model.metrics(train_estimate)
                         }
@@ -87,7 +88,7 @@ class NMEC:
                     'No Training Estimate, check if Type is SLR, 2P, 3PH, or 3PC')
   
 
-    def example(self, model_type="3PH"):
+    def example(self, model_type=None):
         print("modeling with type", model_type)
 
         df = pd.read_csv(
