@@ -1,4 +1,4 @@
-from Model import Model
+from .Model import Model
 import pandas as pd
 import numpy as np
 from sklearn.linear_model import LinearRegression
@@ -6,7 +6,8 @@ from sklearn.linear_model import LinearRegression
 
 class TOWTModel(Model):
 
-    def __init__(self, df=None, dependent_col="load", temperature_col="temp",
+    def __init__(self, df=None, dependent_col="load",                 
+    temperature_col="temp",
                  occupancy_col=None, dependent_df=None, temperature_df=None,
                  additional_vars_df=None, occ_threshold=0.65,
                  knot_temps=[40, 55, 65, 80, 90], define_knot_temps=True,
